import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            defaultValue: PropTypes.string,
            onClick: PropTypes.func,
            onTouchableBlur: PropTypes.func,
            onTouchableChange: PropTypes.func,
            onTouchableFocus: PropTypes.func,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                defaultValue: null,
                onClick: () => {},
                onTouchableBlur: () => {},
                onTouchableChange: (/* evt */) => {},
                onTouchableFocus: () => {},
                value: null
            };
        },

        render() {
            const { defaultValue, onClick, onTouchableBlur, onTouchableChange, onTouchableFocus, value } = this.props;
            return (
                <div
                    className={ block('control') }
                    onClick={ onClick }>
                    <input
                        type="date"
                        defaultValue={ defaultValue }
                        className={ block('control-input-date') }
                        onChange={ onTouchableChange }
                        onBlur={ onTouchableBlur }
                        onFocus={ onTouchableFocus } />
                    <i className={ block('control-icon') } />
                    <div className={ block('control-text') }>{ value }</div>
                </div>
            );
        }
    });

};
